@@ -3,7 +3,6 @@ using System.Runtime.InteropServices;
 
 namespace Test {
     public static class Program {
-        public delegate int HelloFunc(IntPtr arg, int argLength);
         public static int Hello(IntPtr arg, int argLength) {
             Console.WriteLine("Hello from C#!");
             return 42;
@@ -13,6 +12,11 @@ namespace Test {
             return 0;
         }
 
+        public delegate void CustomHelloFunc();
+        public static void CustomHello() {
+            Console.WriteLine("Hello from C#!");
+        }
+
         [UnmanagedCallersOnly]
         public static int UnmanagedHello() {
             return Hello(default, default);
